# Frameworks: Product Strategy

These are the mental models that world-class product strategists use to think about problems. Internalize these, and you'll make better decisions faster.

---

## 1. The Product-Market Fit Pyramid

```
                    ▲ SCALE
                   /│\
                  / │ \
                 /  │  \   ← Growth that works
                /   │   \
               /────│────\  GROWTH METRICS
              /     │     \
             /      │      \  ← Scalable acquisition
            /───────│───────\  DISTRIBUTION
           /        │        \
          /         │         \  ← Monetization works
         /──────────│──────────\  BUSINESS MODEL
        /           │           \
       /            │            \  ← Users get and love it
      /─────────────│─────────────\  PRODUCT (UX + Features)
     /              │              \
    /               │               \  ← Real problem, real demand
   /────────────────│────────────────\  MARKET (Problem + Customer)
  ▼ FOUNDATION
```

**How to use:**
- Build from bottom up
- Each layer must be solid before adding the next
- Most failures come from scaling before the foundation is set
- If growth isn't working, the problem is usually in a lower layer

**Warning signs of layer skipping:**
- Spending on growth before retention works
- Building features before validating problem
- Optimizing conversion before product-market fit

---

## 2. The Four Forces of Progress

When customers switch to a new solution, four forces are at play:

```
                    PUSH
            (Problems with current)
                     │
                     ▼
     ┌───────────────────────────────┐
     │                               │
HABIT │     CUSTOMER'S              │ PULL
(Stay)│     DECISION                │ (New solution)
◄─────│        ZONE                 │─────►
     │                               │
     └───────────────────────────────┘
                     ▲
                     │
                 ANXIETY
           (Fear of new solution)
```

**Forces driving change:**
- **Push:** Pain with current solution
- **Pull:** Attraction of new solution

**Forces resisting change:**
- **Habit:** Comfort with current way
- **Anxiety:** Fear of switching/new

**To win:**
- Increase Push (help them feel the pain)
- Increase Pull (show the better future)
- Reduce Habit (make switching easy)
- Reduce Anxiety (social proof, guarantees)

---

## 3. The Hook Model

How products create habit-forming engagement:

```
TRIGGER ──► ACTION ──► VARIABLE REWARD ──► INVESTMENT
   │                                            │
   └────────────────────────────────────────────┘
                     CYCLE
```

**Components:**
1. **Trigger:** External (notification) or Internal (emotion)
2. **Action:** Simplest behavior in anticipation of reward
3. **Variable Reward:** Unpredictable satisfaction
4. **Investment:** User puts something in (data, effort, social)

**Application:**
- Map your current product to this cycle
- Identify where the cycle breaks
- Internal triggers are stronger than external
- Investment creates switching costs

---

## 4. The Kano Model

Categorizing features by customer satisfaction impact:

```
SATISFACTION
     ▲
     │           ╱ Delighters
     │         ╱  (Unexpected joy)
     │       ╱
     │     ╱
     │   ╱
─────┼──╱────────────────► FUNCTIONALITY
     │╱
   ──┼───────────────────
    ╱│     Performance
  ╱  │     (More is better)
╱    │
     │
     │  ─────────────────
     │        Basics
     │    (Must have or fail)
```

**Feature Categories:**

| Type | Absent | Present | Example |
|------|--------|---------|---------|
| **Basic** | Dissatisfied | Neutral | App doesn't crash |
| **Performance** | Dissatisfied | Satisfied | Faster loading |
| **Delighter** | Neutral | Delighted | Unexpected feature |

**Strategic implications:**
- Basics: Don't skip these (table stakes)
- Performance: Competitors compete here
- Delighters: Differentiation opportunity, but become basics over time

---

## 5. The Technology Adoption Lifecycle

```
                    ┌───────────────────────┐
                    │                       │
              ╱\    │        ╱\            │     ╱\
            ╱    \  │      ╱    \          │   ╱    \
          ╱        \│    ╱        \        │ ╱        \
        ╱     2.5%  │  13.5%   34%  \   34%│    16%     \
       ╱  Innovators│ Early   Early │ Late│  Laggards   \
      ╱             │Adopters Majority│Majority         \
     ╱              │    │   │        │    │             \
    ╱               │    │   │ CHASM  │    │              \
   ╱                │    │   │   ▼    │    │               \
                    │    │   │████████│    │
                    └────┴───┴────────┴────┘
```

**The Chasm:**
- Gap between early adopters and early majority
- Early adopters buy for different reasons (innovation, edge)
- Early majority wants proven, complete solutions
- Many products die in the chasm

**Crossing the chasm:**
1. Pick a single beachhead segment
2. Create "whole product" for that segment
3. Dominate it completely
4. Use as reference to expand

---

## 6. The Strategyzer Business Model Canvas

```
┌───────────────┬───────────────┬───────────────┬───────────────┬───────────────┐
│  Key Partners │Key Activities │     Value     │   Customer    │   Customer    │
│               │               │  Propositions │ Relationships │   Segments    │
│ Who helps us? │ What do we do?│What value do  │ How do we get │ Who do we     │
│               │               │ we deliver?   │ and keep them?│ serve?        │
├───────────────┼───────────────┤               ├───────────────┼───────────────┤
│ Key Resources │               │               │   Channels    │               │
│               │               │               │               │               │
│ What do we    │               │               │ How do we     │               │
│ need?         │               │               │ reach them?   │               │
├───────────────┴───────────────┴───────────────┴───────────────┴───────────────┤
│                              Cost Structure                                    │
│                       What does it cost to operate?                           │
├───────────────────────────────────────────────────────────────────────────────┤
│                              Revenue Streams                                   │
│                         How do we make money?                                 │
└───────────────────────────────────────────────────────────────────────────────┘
```

**Use for:**
- Visualizing entire business model
- Identifying dependencies and risks
- Comparing model alternatives
- Team alignment on strategy

---

## 7. The Three Horizons of Growth

```
VALUE
  ▲
  │                                           Horizon 3
  │                                          (Create future)
  │                                         ╱
  │                           Horizon 2    ╱
  │                          (Build new)  ╱
  │                         ╱            ╱
  │           Horizon 1    ╱            ╱
  │          (Optimize)   ╱            ╱
  │         ╱            ╱            ╱
  │        ╱            ╱            ╱
  │       ╱            ╱            ╱
  │      ╱            ╱            ╱
  └─────┴────────────┴────────────┴──────────► TIME
       NOW         NEAR          FAR
```

**Horizons:**
- **H1:** Current core business (optimize, defend)
- **H2:** Emerging opportunities (build, experiment)
- **H3:** Future possibilities (explore, bet)

**Resource allocation:**
- H1: 70% (keep the lights on)
- H2: 20% (build next growth engine)
- H3: 10% (big bets, R&D)

**Common mistake:** All resources on H1, no investment in H2/H3

---

## 8. The Jobs To Be Done Forces Interview

Questions to uncover switching behavior:

**Timeline:**
1. "When did you first start looking for a solution?"
2. "What was happening that made you start looking?"
3. "What did you try first?"
4. "What finally made you decide to switch?"

**Push (Current pain):**
- "What was frustrating about your old way?"
- "Can you describe the last time it really bothered you?"

**Pull (New solution appeal):**
- "What attracted you to [product]?"
- "What did you hope would happen?"

**Anxiety (Fears):**
- "What concerns did you have?"
- "What almost stopped you from switching?"

**Habit (Inertia):**
- "What did you like about the old way?"
- "What did you think you might miss?"

---

## 9. The Value Hierarchy

```
         ▲
        ╱│╲     SELF-TRANSCENDENCE
       ╱ │ ╲    (Bigger purpose)
      ╱  │  ╲
     ╱───│───╲  SELF-ACTUALIZATION
    ╱    │    ╲ (Achievement, mastery)
   ╱─────│─────╲ EMOTIONAL
  ╱      │      ╲ (How it makes you feel)
 ╱───────│───────╲ FUNCTIONAL
╱        │        ╲ (What it does)
──────────────────── BASE
```

**Levels of value (ascending):**
1. **Functional:** Does the job (table stakes)
2. **Emotional:** Feels good to use (differentiation)
3. **Self-actualization:** Makes me better (loyalty)
4. **Self-transcendence:** Bigger than me (evangelism)

**Strategic application:**
- Competing on functional value is a price war
- Move up the hierarchy for differentiation and margin
- Best products create meaning, not just utility

---

## 10. The RICE Prioritization Framework

```
RICE = (Reach × Impact × Confidence) / Effort

Reach: How many users/customers affected per time period?
Impact: How much will it move the needle? (0.25 = minimal, 3 = massive)
Confidence: How sure are we? (100% = high, 50% = low)
Effort: Person-weeks required
```

**Example:**
```
Feature A: Better onboarding
- Reach: 1,000 new users/month
- Impact: 2 (significant activation improvement)
- Confidence: 80%
- Effort: 4 person-weeks

RICE = (1000 × 2 × 0.8) / 4 = 400

Feature B: Dark mode
- Reach: 500 power users/month
- Impact: 0.5 (nice to have)
- Confidence: 100%
- Effort: 2 person-weeks

RICE = (500 × 0.5 × 1.0) / 2 = 125

→ Feature A wins (400 > 125)
```

**Use for:**
- Prioritizing backlog
- Defending decisions with data
- Comparing apples to oranges
